@@ -2,21 +2,8 @@
 
 #include <iostream>
 
-// TODO   add input buffering to pstreambuf
-
 // TODO   abstract process creation and control to a process class.
 
-// TODO   capitalise class names ?
-// basic_pstreambuf -> BasicPStreamBuf
-// basic_opstream   -> BasicOPStream
-// basic_ipstream   -> BasicIPStream
-// basic_pstream    -> BasicPStream
-// basic_rpstream   -> BasicRPStream
-//
-// change Traits to TraitsT ?
-// don't use C and T, could be used by some char_type ?
-// instantiate pstreams() base in pstreambuf ctor() ?
-
 template class redi::basic_pstreambuf<char>;
 template class redi::pstream_common<char>;
 template class redi::basic_pstream<char>;
@@ -51,7 +38,5 @@ int main()
     rpstream who2("id -un");
     if (!(who2.out() >> c))
         return 4;
-
-    return 0;
 }
 
