@@ -1,6 +1,6 @@
 /*
 PStreams - POSIX Process I/O for C++
-Copyright (C) 2002-2008 Jonathan Wakely
+Copyright (C) 2002-2010 Jonathan Wakely
 
 This file is part of PStreams.
 
@@ -197,6 +197,20 @@ int main()
         check_pass(os << "Magic Monkey\n");
     }
 
+    {
+        // test execve() style construction
+        //
+        // This should read the strings on stdin and print them on stdout
+        // prefixed by "STDIN: "
+
+        pstreams::argv_type argv;
+        argv.push_back("sed");
+        argv.push_back("s/^/STDIN: /");
+        opstream os(argv);
+
+        check_pass(os << "Tragic Donkey\n");
+    }
+
     {
         // test unformatted output
         //
@@ -844,8 +858,6 @@ int main()
     }
 
 
-
-
     return exit_status;
 }
 
